@@ -10,17 +10,20 @@ class Output(BaseTransform):
     depending on service, however as a minimum the following formats should be
     supported by all services:
 
-    - jpg (supports quality)
+    - jpg
     - gif
     - png
-    - webp (supports quality)
+    - webp
     """
 
     _id = 'image.output'
 
-    def __init__(self, format, quality=None):
+    def __init__(self, format, quality=None, lossless=None):
         settings = {'format': format}
         if quality is not None:
             settings['quality'] = quality
 
+        if lossless is not None:
+            settings['lossless'] = lossless
+
         super().__init__(settings)
